@@ -38,6 +38,14 @@ void trainWrapperR(float *data, int data_length,
       coreData.globalBmus = new int[coreData.globalBmus_size];
       initializeCodebook(0, coreData.codebook, nSomX, nSomY, nDimensions);
   }
+#ifdef CUDA
+    if(kernelType==DENSE_GPU){
+        int rank = 0;
+        int nProcs = 1;
+        setDevice(rank, nProcs);
+        initializeGpu(data, nVectorsPerRank, nDimensions, nSomX, nSomY);
+    }
+#endif
   ///
   /// Parameters for SOM
   ///
@@ -81,6 +89,11 @@ void trainWrapperR(float *data, int data_length,
       coreData.uMatrix = calculateUMatrix(coreData.codebook, nSomX, nSomY, nDimensions, mapType);
       coreData.uMatrix_size = nSomX * nSomY;
   }
+#ifdef CUDA
+  if (kernelType == DENSE_GPU) {
+      freeGpu();
+  }
+#endif
   if(coreData.codebook != NULL){
       memcpy(codebook, coreData.codebook, sizeof(float) *  codebook_size);
       delete [] coreData.codebook;
