@@ -88,7 +88,12 @@ void trainOneEpochDenseCPU(int itask, float *data, float *numerator,
 #ifdef _OPENMP
         #pragma omp for
 #endif
+#if defined(linux) || defined(__APPLE__)
         for (unsigned int n = 0; n < nVectorsPerRank; n++) {
+#endif
+#ifdef _WIN32
+		for (int n = 0; n < nVectorsPerRank; n++) {
+#endif
             if (itask*nVectorsPerRank+n<nVectors) {
                 /// get the best matching unit
                 get_bmu_coord(codebook, data, nSomY, nSomX,
@@ -107,7 +112,12 @@ void trainOneEpochDenseCPU(int itask, float *data, float *numerator,
 #ifdef _OPENMP
         #pragma omp for
 #endif
-        for (unsigned int som_y = 0; som_y < nSomY; som_y++) {
+#if defined(linux) || defined(__APPLE__)
+		for (unsigned int som_y = 0; som_y < nSomY; som_y++) {
+#endif
+#ifdef _WIN32
+		for (int som_y = 0; som_y < nSomY; som_y++) {
+#endif
             for (unsigned int som_x = 0; som_x < nSomX; som_x++) {
                 localDenominator[som_y*nSomX + som_x] = 0.0;
                 for (unsigned int d = 0; d < nDimensions; d++)
@@ -118,7 +128,12 @@ void trainOneEpochDenseCPU(int itask, float *data, float *numerator,
 #ifdef _OPENMP
         #pragma omp for
 #endif
+#if defined(linux) || defined(__APPLE__)
         for (unsigned int som_y = 0; som_y < nSomY; som_y++) {
+#endif
+#ifdef _WIN32
+		for (int som_y = 0; som_y < nSomY; som_y++) {
+#endif
             for (unsigned int som_x = 0; som_x < nSomX; som_x++) {
                 for (unsigned int n = 0; n < nVectorsPerRank; n++) {
                     if (itask*nVectorsPerRank+n<nVectors) {
